==> jc-1.4.0.tar.gz: java/util/Collections__24SynchronizedListIterator.h <==
// final class java.util.Collections$SynchronizedListIterator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ff59919a089a415 java_util_Collections__24SynchronizedIterator
// @dep_class effaed4c844e715e java_util_Collections__24SynchronizedListIterator

// header file dependencies
// @dep_header java_util_Collections__24SynchronizedIterator

#include "java/util/Collections__24SynchronizedIterator.h"

#ifndef _JC_java_util_Collections__24SynchronizedListIterator_H_
#define _JC_java_util_Collections__24SynchronizedListIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_ListIterator$object;

// Typedefs
typedef struct _jc_java_util_Collections__24SynchronizedListIterator$sub_refs	_jc_java_util_Collections__24SynchronizedListIterator$sub_refs;
typedef struct _jc_java_util_Collections__24SynchronizedListIterator$sub_nonrefs	_jc_java_util_Collections__24SynchronizedListIterator$sub_nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedListIterator$refs	_jc_java_util_Collections__24SynchronizedListIterator$refs;
typedef struct _jc_java_util_Collections__24SynchronizedListIterator$nonrefs	_jc_java_util_Collections__24SynchronizedListIterator$nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedListIterator$object	_jc_java_util_Collections__24SynchronizedListIterator$object;

typedef const struct _jc_java_util_Collections__24SynchronizedListIterator$vmethods	_jc_java_util_Collections__24SynchronizedListIterator$vmethods;
typedef const struct _jc_java_util_Collections__24SynchronizedListIterator$vtable	_jc_java_util_Collections__24SynchronizedListIterator$vtable;
typedef const struct _jc_java_util_Collections__24SynchronizedListIterator$vtype	_jc_java_util_Collections__24SynchronizedListIterator$vtype;

// Constructors
extern void _jc_java_util_Collections__24SynchronizedListIterator$method$_init$e7abb2ade237b937(_jc_env *, struct _jc_java_util_Collections__24SynchronizedListIterator$object *, struct _jc_java_lang_Object$object *, struct _jc_object *);

// Virtual methods
extern void _jc_java_util_Collections__24SynchronizedListIterator$method$add$75d6bd5079bf5583(_jc_env *, struct _jc_java_util_Collections__24SynchronizedListIterator$object *, struct _jc_java_lang_Object$object *);
extern jboolean _jc_java_util_Collections__24SynchronizedListIterator$method$hasPrevious$ba27b2748a9c0636(_jc_env *, struct _jc_java_util_Collections__24SynchronizedListIterator$object *);
extern jint _jc_java_util_Collections__24SynchronizedListIterator$method$nextIndex$d07daaf318c84c0b(_jc_env *, struct _jc_java_util_Collections__24SynchronizedListIterator$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24SynchronizedListIterator$method$previous$ce61ba497a556ff1(_jc_env *, struct _jc_java_util_Collections__24SynchronizedListIterator$object *);
extern jint _jc_java_util_Collections__24SynchronizedListIterator$method$previousIndex$a699da80acbceaa0(_jc_env *, struct _jc_java_util_Collections__24SynchronizedListIterator$object *);
extern void _jc_java_util_Collections__24SynchronizedListIterator$method$set$5d552207ec221301(_jc_env *, struct _jc_java_util_Collections__24SynchronizedListIterator$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24SynchronizedListIterator$method_info$add$75d6bd5079bf5583;
extern _jc_method _jc_java_util_Collections__24SynchronizedListIterator$method_info$hasPrevious$ba27b2748a9c0636;
extern _jc_method _jc_java_util_Collections__24SynchronizedListIterator$method_info$nextIndex$d07daaf318c84c0b;
extern _jc_method _jc_java_util_Collections__24SynchronizedListIterator$method_info$previous$ce61ba497a556ff1;
extern _jc_method _jc_java_util_Collections__24SynchronizedListIterator$method_info$previousIndex$a699da80acbceaa0;
extern _jc_method _jc_java_util_Collections__24SynchronizedListIterator$method_info$set$5d552207ec221301;

// Virtual methods structure
struct _jc_java_util_Collections__24SynchronizedListIterator$vmethods {
	void	(*add$75d6bd5079bf5583)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedListIterator$object *, struct _jc_java_lang_Object$object *);
	jboolean	(*hasPrevious$ba27b2748a9c0636)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedListIterator$object *);
	jint	(*nextIndex$d07daaf318c84c0b)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedListIterator$object *);
	struct _jc_java_lang_Object$object	*(*previous$ce61ba497a556ff1)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedListIterator$object *);
	jint	(*previousIndex$a699da80acbceaa0)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedListIterator$object *);
	void	(*set$5d552207ec221301)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedListIterator$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_java_util_Collections__24SynchronizedListIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24SynchronizedIterator$vmethods	java_util_Collections__24SynchronizedIterator;
	_jc_java_util_Collections__24SynchronizedListIterator$vmethods	java_util_Collections__24SynchronizedListIterator;
};

// Vtype
struct _jc_java_util_Collections__24SynchronizedListIterator$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24SynchronizedListIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedListIterator$sub_refs {
	struct _jc_object	*li;
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedListIterator$refs {
    _jc_java_util_Collections__24SynchronizedListIterator$sub_refs	java_util_Collections__24SynchronizedListIterator;
    _jc_java_util_Collections__24SynchronizedIterator$sub_refs	java_util_Collections__24SynchronizedIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedListIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedListIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24SynchronizedIterator$sub_nonrefs	java_util_Collections__24SynchronizedIterator;
    _jc_java_util_Collections__24SynchronizedListIterator$sub_nonrefs	java_util_Collections__24SynchronizedListIterator;
};

// Object instance structure
struct _jc_java_util_Collections__24SynchronizedListIterator$object {
	_jc_java_util_Collections__24SynchronizedListIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24SynchronizedListIterator$vtype	*vtype;
	_jc_java_util_Collections__24SynchronizedListIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24SynchronizedListIterator$vtype _jc_java_util_Collections__24SynchronizedListIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24SynchronizedListIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24SynchronizedListIterator$class_object;

#endif	/* _JC_java_util_Collections__24SynchronizedListIterator_H_ */

==> jc-1.4.6.tar.gz: java/util/Collections__24SynchronizedListIterator.h <==
// final class java.util.Collections$SynchronizedListIterator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ff59919a089a415 java_util_Collections__24SynchronizedIterator
// @dep_class effaed4c844e715e java_util_Collections__24SynchronizedListIterator

// header file dependencies
// @dep_header java_util_Collections__24SynchronizedIterator

#include "java/util/Collections__24SynchronizedIterator.h"

#ifndef _JC_java_util_Collections__24SynchronizedListIterator_H_
#define _JC_java_util_Collections__24SynchronizedListIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_ListIterator$object;

// Typedefs
typedef struct _jc_java_util_Collections__24SynchronizedListIterator$sub_refs	_jc_java_util_Collections__24SynchronizedListIterator$sub_refs;
typedef struct _jc_java_util_Collections__24SynchronizedListIterator$sub_nonrefs	_jc_java_util_Collections__24SynchronizedListIterator$sub_nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedListIterator$refs	_jc_java_util_Collections__24SynchronizedListIterator$refs;
typedef struct _jc_java_util_Collections__24SynchronizedListIterator$nonrefs	_jc_java_util_Collections__24SynchronizedListIterator$nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedListIterator$object	_jc_java_util_Collections__24SynchronizedListIterator$object;

typedef const struct _jc_java_util_Collections__24SynchronizedListIterator$vmethods	_jc_java_util_Collections__24SynchronizedListIterator$vmethods;
typedef const struct _jc_java_util_Collections__24SynchronizedListIterator$vtable	_jc_java_util_Collections__24SynchronizedListIterator$vtable;
typedef const struct _jc_java_util_Collections__24SynchronizedListIterator$vtype	_jc_java_util_Collections__24SynchronizedListIterator$vtype;

// Constructors
extern void _jc_java_util_Collections__24SynchronizedListIterator$method$_init$e7abb2ade237b937(_jc_env *, struct _jc_java_util_Collections__24SynchronizedListIterator$object *, struct _jc_java_lang_Object$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_util_Collections__24SynchronizedListIterator$method$add$75d6bd5079bf5583(_jc_env *, struct _jc_java_util_Collections__24SynchronizedListIterator$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_util_Collections__24SynchronizedListIterator$method$hasPrevious$ba27b2748a9c0636(_jc_env *, struct _jc_java_util_Collections__24SynchronizedListIterator$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_Collections__24SynchronizedListIterator$method$nextIndex$d07daaf318c84c0b(_jc_env *, struct _jc_java_util_Collections__24SynchronizedListIterator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24SynchronizedListIterator$method$previous$ce61ba497a556ff1(_jc_env *, struct _jc_java_util_Collections__24SynchronizedListIterator$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_Collections__24SynchronizedListIterator$method$previousIndex$a699da80acbceaa0(_jc_env *, struct _jc_java_util_Collections__24SynchronizedListIterator$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_Collections__24SynchronizedListIterator$method$set$5d552207ec221301(_jc_env *, struct _jc_java_util_Collections__24SynchronizedListIterator$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24SynchronizedListIterator$method_info$add$75d6bd5079bf5583;
extern _jc_method _jc_java_util_Collections__24SynchronizedListIterator$method_info$hasPrevious$ba27b2748a9c0636;
extern _jc_method _jc_java_util_Collections__24SynchronizedListIterator$method_info$nextIndex$d07daaf318c84c0b;
extern _jc_method _jc_java_util_Collections__24SynchronizedListIterator$method_info$previous$ce61ba497a556ff1;
extern _jc_method _jc_java_util_Collections__24SynchronizedListIterator$method_info$previousIndex$a699da80acbceaa0;
extern _jc_method _jc_java_util_Collections__24SynchronizedListIterator$method_info$set$5d552207ec221301;

// Virtual methods structure
struct _jc_java_util_Collections__24SynchronizedListIterator$vmethods {
	void	(*add$75d6bd5079bf5583)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedListIterator$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jboolean	(*hasPrevious$ba27b2748a9c0636)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedListIterator$object *) _JC_JCNI_ATTR;
	jint	(*nextIndex$d07daaf318c84c0b)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedListIterator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*previous$ce61ba497a556ff1)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedListIterator$object *) _JC_JCNI_ATTR;
	jint	(*previousIndex$a699da80acbceaa0)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedListIterator$object *) _JC_JCNI_ATTR;
	void	(*set$5d552207ec221301)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedListIterator$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_Collections__24SynchronizedListIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24SynchronizedIterator$vmethods	java_util_Collections__24SynchronizedIterator;
	_jc_java_util_Collections__24SynchronizedListIterator$vmethods	java_util_Collections__24SynchronizedListIterator;
};

// Vtype
struct _jc_java_util_Collections__24SynchronizedListIterator$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24SynchronizedListIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedListIterator$sub_refs {
	struct _jc_object	*li;
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedListIterator$refs {
    _jc_java_util_Collections__24SynchronizedListIterator$sub_refs	java_util_Collections__24SynchronizedListIterator;
    _jc_java_util_Collections__24SynchronizedIterator$sub_refs	java_util_Collections__24SynchronizedIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedListIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedListIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24SynchronizedIterator$sub_nonrefs	java_util_Collections__24SynchronizedIterator;
    _jc_java_util_Collections__24SynchronizedListIterator$sub_nonrefs	java_util_Collections__24SynchronizedListIterator;
};

// Object instance structure
struct _jc_java_util_Collections__24SynchronizedListIterator$object {
	_jc_java_util_Collections__24SynchronizedListIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24SynchronizedListIterator$vtype	*vtype;
	_jc_java_util_Collections__24SynchronizedListIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24SynchronizedListIterator$vtype _jc_java_util_Collections__24SynchronizedListIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24SynchronizedListIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24SynchronizedListIterator$class_object;

#endif	/* _JC_java_util_Collections__24SynchronizedListIterator_H_ */
